@@ -17,6 +17,9 @@
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse at d.umn.edu
 #
+# Ying Liu, University of Minnesota
+# liux0935 at umn.edu
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -135,6 +138,18 @@ UMLS::Similarity::cdist - Perl module for computing semantic relatedness
 of concepts in the UMLS by simple edge counting proposed by Rada, et. al. 
 (1989).
 
+=head1 CITATION
+
+ @article{Rada89,
+  title={{Development and application of a metric on semantic nets}},
+  author={Rada, R. and Mili, H. and Bicknell, E. and Blettner, M.},
+  journal={IEEE transactions on systems, man and cybernetics},
+  volume={19},
+  number={1},
+  pages={17--30},
+  year={1989}
+ }
+
 =head1 SYNOPSIS
 
   use UMLS::Interface;
@@ -236,7 +251,7 @@ perl(1), UMLS::Similarity(3)
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004-2010 by Bridget T McInnes, Siddharth Patwardhan, 
-Serguei Pakhomov and Ted Pedersen
+Serguei Pakhomov, Ying Liu and Ted Pedersen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
