@@ -17,6 +17,9 @@
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse at d.umn.edu
 #
+# Ying Liu, University of Minnesota
+# liux0935 at umn.edu
+#
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -158,6 +161,18 @@ UMLS::Similarity::nam - Perl module for computing semantic relatedness
 of concepts in the Unified Medical Language System (UMLS) using the 
 method described by Nguyen and Al-Mubaid (2006)
 
+=head1 CITATION
+
+ @inproceedings{NguyenA06,
+  title={{New ontology-based semantic similarity measure 
+          for the biomedical domain}},
+  author={Nguyen, H.A. and Al-Mubaid, H.},
+  booktitle={Proceedings of the IEEE International Conference 
+             on Granular Computing},
+  pages={623--628},
+  year={2006}
+ }
+
 =head1 SYNOPSIS
 
   use UMLS::Interface;
@@ -258,7 +273,7 @@ perl(1), UMLS::Similarity(3)
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004-2010 by Bridget T McInnes, Siddharth Patwardhan, 
-Serguei Pakhomov and Ted Pedersen
+Serguei Pakhomov, Ying Liu and Ted Pedersen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
