@@ -17,6 +17,9 @@
 # Ted Pedersen, University of Minnesota, Duluth
 # tpederse at d.umn.edu
 #
+# Ying Liu, University of Minnesota
+# liux0935 at umn.edu
+# 
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -135,6 +138,19 @@ UMLS::Similarity::res - Perl module for computing the semantic
 relatednessof concepts in the Unified Medical Language System 
 (UMLS) using the method described by Resnik (1995).
 
+=head1 CITATION
+
+ @article{Resnik95,
+  title={{Using information content to evaluate semantic 
+          similarity in a taxonomy}},
+  author={Resnik, P.},
+  journal={Proceedings of the 14th International Joint 
+           Conference on Artificial Intelligence},
+  volume={1},
+  pages={448--453},
+  year={1995}
+ }
+
 =head1 SYNOPSIS
 
   use UMLS::Interface;
@@ -171,7 +187,28 @@ relatednessof concepts in the Unified Medical Language System
 This module computes the semantic relatedness of two concepts in 
 the UMLS according to a method described by Resnik (1995). The 
 relatedness measure proposed by Resnik is the information content 
-of the least common subsumer of the two concepts. 
+(IC) of the least common subsumer of the two concepts. 
+
+The IC of a concept is defined as the negative log of the probabilty 
+of the concept. 
+
+To use this measure, a propagation file containing the probability 
+of a CUI for each of the CUIs from the source(s) specified in the 
+configuration file. The format for this file is as follows:
+
+ C0000039<>0.00003951
+ C0000052<>0.00003951
+ C0000084<>0.00003951
+ C0000096<>0.00003951
+
+A larger of example of this file can be found in the icpropagation file 
+in the samples/ directory. In order to create a propagation file given 
+
+A propagation file can be created using the create-propagation-file.pl
+program in the utils/ directory. This file will take either a list 
+of CUIs with their frequency counts or a raw text file and compute the 
+probability of each of the CUIs using the set of source(s) and relations 
+specified in the configuration file.
 
 =head1 USAGE
 
@@ -239,7 +276,7 @@ perl(1), UMLS::Similarity(3)
 =head1 COPYRIGHT AND LICENSE
 
 Copyright 2004-2010 by Bridget T McInnes, Siddharth Patwardhan, 
-Serguei Pakhomov and Ted Pedersen
+Serguei Pakhomov, Ying Liu and Ted Pedersen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
